/**
 * apeman react package for card components
 * @class ApCard
 */

'use strict'

import React, { PropTypes as types, Component } from 'react'
import classnames from 'classnames'
import { ApImage } from 'apeman-react-image'
import { ApTouchable } from 'apeman-react-touchable'
import { clone } from 'asobj'

/** @lends ApCard */
class ApCard extends Component {

  // --------------------
  // Specs
  // --------------------
  render () {
    const s = this
    let { state, props } = s
    let {
      title,
      children
    } = props
    let touchableProps = clone({
      without: [ 'title', 'children' ]
    })
    return (
      <ApTouchable { ...touchableProps }
                   className={ classnames('ap-card', {
                     'ap-card-tappable': !!props.onTap
                   }, props.className) }
                   style={ Object.assign({}, props.style) }>
        <div className='ap-card-inner'>
          <ApCard.Header title={ title }/>
          <ApCard.Body title={ children }/>
        </div>
      </ApTouchable>
    )
  }
}

Object.assign(ApCard, {
  propTypes: {
    title: types.string
  },

  Header ({ title }) {
    if (!title) {
      return null
    }
    return (
      <div className='ap-card-header'>
        <div className='ap-card-title'>{ title } </div>
      </div>
    )
  },

  Body ({ children }) {
    return (
      <div className='ap-card-body'>
        { children }
      </div>
    )
  }
})

export default ApCard
